@@ -6,5 +6,5 @@ class JsonateResponse(HttpResponse):
     Subclass of HttpResponse that turns just about anything into JSON
     via jsonate() and returns the result with mimetype "application/json"
     """
-    def __init__(self, data):
-        super(JsonateResponse, self).__init__(content=jsonate(data), mimetype='application/json')
\ No newline at end of file
+    def __init__(self, content, mimetype='application/json', *args, **kwargs):
+        super(JsonateResponse, self).__init__(jsonate(content), mimetype, *args, **kwargs)
\ No newline at end of file
